@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002 the xine project
+ * Copyright (C) 2002-2003 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -15,29 +15,27 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
- *
- * $Id: pnm.h,v 1.2 2002/12/12 22:08:15 holstsn Exp $
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
  *
  * pnm util functions header by joschka
  */
- 
+
 #ifndef HAVE_PNM_H
 #define HAVE_PNM_H
 
 #ifndef __CYGWIN__
 #include <inttypes.h>
 #endif
-/*#include "xine_internal.h" */
+#include "xine_internal.h"
 
 typedef struct pnm_s pnm_t;
 
-pnm_t*   pnm_connect (const char *url);
+pnm_t*   pnm_connect (xine_stream_t *stream, const char *url);
 
 int      pnm_read (pnm_t *this, char *data, int len);
 void     pnm_close (pnm_t *this);
 
-int      pnm_peek_header (pnm_t *this, char *data);
+int      pnm_peek_header (pnm_t *this, char *data, int maxsize);
 
 #endif
 
