@@ -97,7 +97,7 @@ static vo_frame_t *macosx_alloc_frame(vo_driver_t *vo_driver) {
   /* macosx_driver_t *this = (macosx_driver_t *) vo_driver; */
   macosx_frame_t  *frame;
   
-  frame = (macosx_frame_t *) xine_xmalloc(sizeof(macosx_frame_t));
+  frame = calloc(1, sizeof(macosx_frame_t));
   if(!frame)
     return NULL;
 
@@ -320,7 +320,7 @@ static vo_driver_t *open_plugin(video_driver_class_t *driver_class, const void *
   macosx_driver_t   *driver;
   XineOpenGLView    *view = (XineOpenGLView *) visual;
   
-  driver = (macosx_driver_t *) xine_xmalloc(sizeof(macosx_driver_t));
+  driver = calloc(1, sizeof(macosx_driver_t));
 
   driver->config = class->config;
   driver->xine   = class->xine;
@@ -366,7 +366,7 @@ static void dispose_class (video_driver_class_t *driver_class) {
 static void *init_class (xine_t *xine, void *visual) {
   macosx_class_t        *this;
   
-  this = (macosx_class_t *) xine_xmalloc(sizeof(macosx_class_t));
+  this = calloc(1, sizeof(macosx_class_t));
 
   this->driver_class.open_plugin     = open_plugin;
   this->driver_class.get_identifier  = get_identifier;
